@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: conflogin.php,v 1.34 2005/06/28 15:46:41 gruberroland Exp $
+$Id: conflogin.php,v 1.39 2006/04/16 12:44:18 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,23 +41,14 @@ session_save_path("../../sess");
 
 setlanguage();
 
+// get error message from confmain.php
+if (isset($_SESSION['conf_message'])) $message = $_SESSION['conf_message'];
+
 // remove settings from session
-unset($_SESSION['conf_passwd']);
-unset($_SESSION['conf_passwd1']);
-unset($_SESSION['conf_passwd2']);
-unset($_SESSION['conf_serverurl']);
-unset($_SESSION['conf_admins']);
-unset($_SESSION['conf_suffusers']);
-unset($_SESSION['conf_suffgroups']);
-unset($_SESSION['conf_suffhosts']);
-unset($_SESSION['conf_usrlstattr']);
-unset($_SESSION['conf_grplstattr']);
-unset($_SESSION['conf_hstlstattr']);
-unset($_SESSION['conf_maxlistentries']);
-unset($_SESSION['conf_lang']);
-unset($_SESSION['conf_scriptpath']);
-unset($_SESSION['conf_scriptserver']);
-unset($_SESSION['conf_filename']);
+$sessionKeys = array_keys($_SESSION);
+for ($i = 0; $i < sizeof($sessionKeys); $i++) {
+	if (substr($sessionKeys[$i], 0, 5) == "conf_") unset($_SESSION[$sessionKeys[$i]]);
+}
 
 echo $_SESSION['header'];
 
@@ -82,7 +73,7 @@ echo $_SESSION['header'];
 			echo "//-->\n";
 			echo "</script>\n";
 		?>
-		<p align="center"><a href="http://lam.sf.net" target="_blank">
+		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
 			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</p>
 		<hr><br><br>
@@ -95,13 +86,12 @@ echo $_SESSION['header'];
 				<td style="border-style:none" rowspan="3" width="20"></td>
 			</tr>
 			<tr>
-				<td style="border-style:none" align="center"><b> <?php echo _("Please enter password to change preferences:"); ?> </b></td>
+				<td style="border-style:none" align="center"><b> <?php echo _("Please enter your password to change the server preferences:"); ?> </b></td>
 			</tr>
 			<tr><td style="border-style:none" >&nbsp;</td></tr>
 <?php
-	if (!isset($message)) $message = "";
 	$files = getConfigProfiles();
-	if (sizeof($files) < 1) $message = _("No configuration profiles found. Please create one.");
+	if (sizeof($files) < 1) $message = _("No server profiles found. Please create one.");
 	// print message if login was incorrect or no config profiles are present
 	if (isset($message)) {  // $message is set by confmain.php (requires conflogin.php then)
 		echo "<tr>\n";
@@ -146,7 +136,7 @@ echo $_SESSION['header'];
 			</tr>
 			<tr>
 				<td style="border-style:none" align="center">
-					<b><a href="profmanage.php"><?php echo _("Manage profiles") ?></a></b>
+					<b><a href="profmanage.php"><?php echo _("Manage server profiles") ?></a></b>
 				</td>
 			</tr>
 			<tr>
