@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php,v 1.67 2005/04/26 15:50:29 gruberroland Exp $
+$Id: confmain.php,v 1.76 2006/04/16 12:43:53 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003-04  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,10 +31,10 @@ $Id: confmain.php,v 1.67 2005/04/26 15:50:29 gruberroland Exp $
 
 
 /** Access to config functions */
-include_once ("../../lib/config.inc");
+include_once("../../lib/config.inc");
 
 /** access to module settings */
-include_once ("../../lib/modules.inc");
+include_once("../../lib/modules.inc");
 
 // start session
 session_save_path("../../sess");
@@ -42,103 +42,75 @@ session_save_path("../../sess");
 
 setlanguage();
 
-// check if button was pressed and if we have to save the setting or go back to login
-if (isset($_POST['back']) || isset($_POST['submitconf']) || isset($_POST['editmodules'])){
-	// save settings
-	if ($_POST['submitconf'] || $_POST['editmodules']){
-		// save HTTP-POST variables in session
-		$_SESSION['conf_passwd'] = $_POST['passwd'];
-		$_SESSION['conf_passwd1'] = $_POST['passwd1'];
-		$_SESSION['conf_passwd2'] = $_POST['passwd2'];
-		$_SESSION['conf_serverurl'] = $_POST['serverurl'];
-		$_SESSION['conf_cachetimeout'] = $_POST['cachetimeout'];
-		$_SESSION['conf_admins'] = $_POST['admins'];
-		$_SESSION['conf_suffusers'] = $_POST['suffusers'];
-		$_SESSION['conf_suffgroups'] = $_POST['suffgroups'];
-		$_SESSION['conf_suffhosts'] = $_POST['suffhosts'];
-		$_SESSION['conf_suffdomains'] = $_POST['suffdomains'];
-		$_SESSION['conf_sufftree'] = $_POST['sufftree'];
-		$_SESSION['conf_usrlstattr'] = $_POST['usrlstattr'];
-		$_SESSION['conf_grplstattr'] = $_POST['grplstattr'];
-		$_SESSION['conf_hstlstattr'] = $_POST['hstlstattr'];
-		$_SESSION['conf_maxlistentries'] = $_POST['maxlistentries'];
-		$_SESSION['conf_lang'] = $_POST['lang'];
-		$_SESSION['conf_scriptpath'] = $_POST['scriptpath'];
-		$_SESSION['conf_scriptserver'] = $_POST['scriptserver'];
-		$_SESSION['conf_usermodules'] = explode(",", $_POST['usermodules']);
-		$_SESSION['conf_groupmodules'] = explode(",", $_POST['groupmodules']);
-		$_SESSION['conf_hostmodules'] = explode(",", $_POST['hostmodules']);
-		$_SESSION['conf_filename'] = $_POST['filename'];
-		$modSettings = array_keys($_SESSION['config_types']);
-		for ($i = 0; $i < sizeof($modSettings); $i++) $_SESSION['config_moduleSettings'][$modSettings[$i]] = $_POST[$modSettings[$i]];
-	}
-	// go to final page
-	if ($_POST['submitconf']){
-		metaRefresh("confsave.php");
-	}
-	// go to modules page
-	elseif ($_POST['editmodules']){
-		metaRefresh("confmodules.php");
-	}
-	// back to login
-	else if ($_POST['back']){
-		metaRefresh("../login.php");
-	}
-	exit;
-}
-
-// get password if register_globals is off
+// get password
 if (isset($_POST['passwd'])) $passwd = $_POST['passwd'];
-if (isset($_GET["modulesback"])) $passwd = $_SESSION['conf_passwd'];
+if (isset($_GET["modulesback"]) || isset($_GET["typesback"])) $passwd = $_SESSION['conf_config']->get_Passwd();
 
 // check if password was entered
 // if not: load login page
 if (! $passwd) {
-	$message = _("No password was entered!");
+	$_SESSION['conf_message'] = _("No password was entered!");
 	/** go back to login if password is empty */
 	require('conflogin.php');
 	exit;
 }
 
-$filename = $_POST['filename'];
-if (isset($_GET["modulesback"])) $filename = $_SESSION['conf_filename'];
-$conf = new Config($filename);
+if (!isset($_SESSION['conf_config']) && isset($_POST['filename'])) {
+	$_SESSION['conf_config'] = new Config($_POST['filename']);	
+}
+$conf = &$_SESSION['conf_config'];
 
 // check if password is valid
 // if not: load login page
 if (!(($conf->get_Passwd()) == $passwd)) {
-	$message = _("The password is invalid! Please try again.");
+	$sessionKeys = array_keys($_SESSION);
+	for ($i = 0; $i < sizeof($sessionKeys); $i++) {
+		if (substr($sessionKeys[$i], 0, 5) == "conf_") unset($_SESSION[$sessionKeys[$i]]);
+	}
+	$_SESSION['conf_message'] = _("The password is invalid! Please try again.");
 	/** go back to login if password is invalid */
 	require('conflogin.php');
 	exit;
 }
 
-// check if user comes from modules page
-if (isset($_GET["modulesback"])) {
-	// load config values from session
-	$conf->set_ServerURL($_SESSION['conf_serverurl']);
-	$conf->set_cacheTimeout($_SESSION['conf_cachetimeout']);
-	$conf->set_Adminstring($_SESSION['conf_admins']);
-	$conf->set_Suffix('user', $_SESSION['conf_suffusers']);
-	$conf->set_Suffix('group', $_SESSION['conf_suffgroups']);
-	$conf->set_Suffix('host', $_SESSION['conf_suffhosts']);
-	$conf->set_Suffix('domain', $_SESSION['conf_suffdomains']);
-	$conf->set_Suffix('tree', $_SESSION['conf_sufftree']);
-	$conf->set_listAttributes($_SESSION['conf_usrlstattr'], 'user');
-	$conf->set_listAttributes($_SESSION['conf_grplstattr'], 'group');
-	$conf->set_listAttributes($_SESSION['conf_hstlstattr'], 'host');
-	$conf->set_MaxListEntries($_SESSION['conf_maxlistentries']);
-	$conf->set_defaultLanguage($_SESSION['conf_lang']);
-	$conf->set_scriptpath($_SESSION['conf_scriptpath']);
-	$conf->set_scriptserver($_SESSION['conf_scriptserver']);
-	// check if modules were edited
-	if ($_GET["moduleschanged"] == "true") {
-		$conf->set_AccountModules($_SESSION['conf_usermodules'], 'user');
-		$conf->set_AccountModules($_SESSION['conf_groupmodules'], 'group');
-		$conf->set_AccountModules($_SESSION['conf_hostmodules'], 'host');
+// check if button was pressed and if we have to save the setting or go back to login
+if (isset($_POST['back']) || isset($_POST['submitconf']) || isset($_POST['editmodules']) || isset($_POST['edittypes'])){
+	// go to final page
+	if ($_POST['submitconf']){
+		saveSettings();
+	}
+	// go to modules page
+	elseif ($_POST['editmodules']){
+		metaRefresh("confmodules.php");
+		exit;
+	}
+	// go to types page
+	elseif ($_POST['edittypes']){
+		metaRefresh("conftypes.php");
+		exit;
+	}
+	// back to login
+	else if ($_POST['back']){
+		metaRefresh("../login.php");
+		exit;
 	}
 }
 
+
+// check if user comes from types page
+if (isset($_GET["typesback"])) {
+	// check if a new account type was added
+	if (isset($_GET["typeschanged"])) {
+		metaRefresh("confmodules.php");
+		exit;		
+	}
+}
+
+// type information
+if (!isset($_SESSION['conf_accountTypes'])) $_SESSION['conf_accountTypes'] = $conf->get_ActiveTypes();
+if (!isset($_SESSION['conf_accountTypesOld'])) $_SESSION['conf_accountTypesOld'] = $conf->get_ActiveTypes();
+if (!isset($_SESSION['conf_typeSettings'])) $_SESSION['conf_typeSettings'] = $conf->get_typeSettings();
+
 // index for tab order
 $tabindex = 1;
 $tabindexLink = 1000;
@@ -149,9 +121,17 @@ echo ("<title>" . _("LDAP Account Manager Configuration") . "</title>\n");
 echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n");
 echo ("</head>\n");
 echo ("<body>\n");
-echo ("<p align=\"center\"><a href=\"http://lam.sf.net\" target=\"new_window\">".
+echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p></p>\n");
 
+// display error messages
+if (isset($_SESSION['conf_errors'])) {
+	for ($i = 0; $i < sizeof($_SESSION['conf_errors']); $i++) {
+		call_user_func_array('StatusMessage', $_SESSION['conf_errors'][$i]);
+	}
+	echo "<br>";
+}
+
 // display formular
 echo ("<form action=\"confmain.php\" method=\"post\">\n");
 
@@ -172,49 +152,9 @@ $tabindex++;
 // new line
 echo ("<tr><td colspan=3>&nbsp</td></tr>");
 
-// user suffix
-echo ("<tr><td align=\"right\"><b>".
-	_("UserSuffix") . ": </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"suffusers\" value=\"" . $conf->get_Suffix('user') . "\"></td>\n");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=202\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-// group suffix
-echo ("<tr><td align=\"right\"><b>".
-	_("GroupSuffix") . ": </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"suffgroups\" value=\"" . $conf->get_Suffix('group') . "\"></td>\n");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=202\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-// host suffix
-echo ("<tr><td align=\"right\"><b>".
-	_("HostSuffix") . ": </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"suffhosts\" value=\"" . $conf->get_Suffix('host') . "\"></td>\n");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=202\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-// domain suffix
-echo ("<tr><td align=\"right\"><b>".
-	_("DomainSuffix") . " **: </b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"suffdomains\" value=\"" . $conf->get_Suffix('domain') . "\"></td>\n");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=202\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
 // tree suffix
 echo ("<tr><td align=\"right\"><b>".
-	_("TreeSuffix") . ": </b></td>".
+	_("Tree suffix") . ": </b></td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"sufftree\" value=\"" . $conf->get_Suffix('tree') . "\"></td>\n");
 echo "<td>";
 echo "<a href=\"../help.php?HelpNumber=203\" target=\"lamhelp\">";
@@ -249,22 +189,22 @@ echo ("</fieldset>");
 
 echo ("<p></p>");
 
-echo ("<fieldset><legend><b>" . _("Account modules") . "</b></legend>");
-echo ("<table border=0>");
+echo ("<fieldset><legend><b>" . _("Account types and modules") . "</b></legend>");
 
 // Account modules
-echo "<tr><td><b>" . _("User modules") . ": </b>" . implode(", ", $conf->get_AccountModules('user')) . "</td></tr>\n";
-echo "<tr><td><b>" . _("Group modules") . ": </b>" . implode(", ", $conf->get_AccountModules('group')) . "</td></tr>\n";
-echo "<tr><td><b>" . _("Host modules") . ": </b>" . implode(", ", $conf->get_AccountModules('host')) . "</td></tr>\n";
-echo "<tr><td>&nbsp;</td></tr>\n";
-echo "<tr><td><input tabindex=\"$tabindex\" type=\"submit\" name=\"editmodules\" value=\"" . _("Edit modules") . "\">&nbsp;&nbsp;";
+$types = $conf->get_ActiveTypes();
+for ($i = 0; $i < sizeof($types); $i++) {
+	echo "<b>" . getTypeAlias($types[$i]) . ": </b>" . implode(", ", $conf->get_AccountModules($types[$i])) . "<br>\n";
+}
+echo "<br>\n";
+echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"edittypes\" value=\"" . _("Edit account types") . "\">&nbsp;&nbsp;";
+$tabindex++;
+echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"editmodules\" value=\"" . _("Edit modules") . "\">&nbsp;&nbsp;";
 echo "<a href=\"../help.php?HelpNumber=217\" target=\"lamhelp\">";
 echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
 echo "</a>\n";
-echo "</td></tr>\n";
 $tabindex++;
 
-echo ("</table>");
 echo ("</fieldset>");
 
 echo ("<p></p>");
@@ -274,12 +214,10 @@ echo ("<p></p>");
 
 // get list of scopes of modules
 $scopes = array();
-$mods = $conf->get_AccountModules('user');
-for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = 'user';
-$mods = $conf->get_AccountModules('group');
-for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = 'group';
-$mods = $conf->get_AccountModules('host');
-for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = 'host';
+for ($m = 0; $m < sizeof($types); $m++) {
+	$mods = $conf->get_AccountModules($types[$m]);
+	for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = $types[$m];
+}
 
 // get module options
 $options = getConfigOptions($scopes);
@@ -288,59 +226,24 @@ $old_options = $conf->get_moduleSettings();
 // get module descriptions
 $moduleDescriptions = getConfigDescriptions();
 
-// save scopes
-$_SESSION['config_scopes'] = $scopes;
 
 // display module boxes
 $modules = array_keys($options);
-$_SESSION['config_types'] = array();
+$_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
 	if (sizeof($options[$modules[$i]]) < 1) continue;
 	echo "<fieldset>\n";
 	echo "<legend><b>" . $moduleDescriptions['legend'][$modules[$i]] . "</b></legend>\n";
 	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, $tabindexLink, 'config');
-	$_SESSION['config_types'] = array_merge($configTypes, $_SESSION['config_types']);
+	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
 	echo "</fieldset>\n";
 	echo "<br>";
 }
 
 
-echo ("<fieldset><legend><b>" . _("LDAP List settings") . "</b></legend>\n");
+echo ("<fieldset><legend><b>" . _("List settings") . "</b></legend>\n");
 echo ("<table border=0>\n");
 
-// user list attributes
-echo ("<tr><td align=\"right\"><b>".
-	_("Attributes in User List") . " *:</b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"usrlstattr\" value=\"" . $conf->get_listAttributes('user') . "\"></td>");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=206\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-// group list attributes
-echo ("<tr><td align=\"right\"><b>".
-	_("Attributes in Group List") . " *:</b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"grplstattr\" value=\"" . $conf->get_listAttributes('group') . "\"></td>");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=206\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-// host list attributes
-echo ("<tr><td align=\"right\"><b>".
-	_("Attributes in Host List") . " **:</b></td>".
-	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"hstlstattr\" value=\"" . $conf->get_listAttributes('host') . "\"></td>");
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=206\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-$tabindex++;
-
-echo ("<tr><td colspan=3>&nbsp</td></tr>\n");
-
 // maximum list entries
 echo ("<tr><td align=\"right\"><b>".
 	_("Maximum list entries") . " : </b></td>".
@@ -478,11 +381,10 @@ echo ("<table border=0>\n");
 
 echo "<tr>";
 echo "<td align=\"left\"><pre>";
-	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"submitconf\" value=\"" . _("Submit") . "\">";
+	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"submitconf\" value=\"" . _("Ok") . "\">";
 	$tabindex++;
-	echo "<input tabindex=\"$tabindex\" type=\"reset\" name=\"resetconf\" value=\"" . _("Reset") . "\">";
-	$tabindex++;
-	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"back\" value=\"" . _("Abort") . "\"\n";
+	echo "&nbsp;";
+	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"back\" value=\"" . _("Cancel") . "\"\n";
 	$tabindex++;
 
 echo ("></pre></td></tr>\n");
@@ -497,18 +399,122 @@ echo ("<p>** = ". _("required for Samba 3 accounts") . "</p>");
 // password for configuration
 echo ("<p><input type=\"hidden\" name=\"passwd\" value=\"" . $passwd . "\"></p>\n");
 
-// config file
-echo ("<p><input type=\"hidden\" name=\"filename\" value=\"" . $filename . "\"></p>\n");
-
-// modules
-echo ("<p><input type=\"hidden\" name=\"usermodules\" value=\"" . implode(",", $conf->get_AccountModules('user')) . "\"></p>\n");
-echo ("<p><input type=\"hidden\" name=\"groupmodules\" value=\"" . implode(",", $conf->get_AccountModules('group')) . "\"></p>\n");
-echo ("<p><input type=\"hidden\" name=\"hostmodules\" value=\"" . implode(",", $conf->get_AccountModules('host')) . "\"></p>\n");
-
 echo ("</form>\n");
 echo ("</body>\n");
 echo ("</html>\n");
 
 
+/**
+ * Saves the entered settings.
+ *
+ */
+function saveSettings() {
+	$conf = &$_SESSION['conf_config'];
+	$types = $conf->get_ActiveTypes();
+	
+	// remove double slashes if magic quotes are on
+	if (get_magic_quotes_gpc() == 1) {
+		$postKeys = array_keys($_POST);
+		for ($i = 0; $i < sizeof($postKeys); $i++) {
+			if (is_string($_POST[$postKeys[$i]])) $_POST[$postKeys[$i]] = stripslashes($_POST[$postKeys[$i]]);
+		}
+	}
+	// check new preferences
+	$errors = array();
+	if (!$conf->set_ServerURL($_POST['serverurl'])) {
+		$errors[] = array("ERROR", _("Server Address is empty!"));
+	}
+	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
+		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
+	}
+	if (!$conf->set_Adminstring($_POST['admins'])) {
+		$errors[] = array("ERROR", _("List of admin users is empty or invalid!"));
+	}
+	if (!$conf->set_Suffix("tree", $_POST['sufftree'])) {
+		$errors[] = array("ERROR", _("TreeSuffix is invalid!"));
+	}
+	if (!$conf->set_MaxListEntries($_POST['maxlistentries'])) {
+		$errors[] = array("ERROR", _("Max list entries is invalid!"));
+	}
+	if (!$conf->set_defaultLanguage($_POST['lang'])) {
+		$errors[] = array("ERROR", _("Language is not defined!"));
+	}
+	if (!$conf->set_scriptpath($_POST['scriptpath'])) {
+		$errors[] = array("ERROR", _("Script path is invalid!"));
+	}
+	if (!$conf->set_scriptserver($_POST['scriptserver'])) {
+		$errors[] = array("ERROR", _("Script server is invalid!"));
+	}
+	// check if password was changed
+	if (isset($_POST['passwd1']) && ($_POST['passwd1'] != '')) {
+		if ($_POST['passwd1'] != $_POST['passwd2']) {
+			$errors[] = array("ERROR", _("Passwords are different!"));
+		}
+		else {
+			// set new password
+			$conf->set_Passwd($_POST['passwd1']);
+		}
+	}
+
+	// check module options
+	// create option array to check and save
+	$options = array();
+	$opt_keys = array_keys($_SESSION['conf_types']);
+	for ($i = 0; $i < sizeof($opt_keys); $i++) {
+		$element = $opt_keys[$i];
+		// text fields
+		if ($_SESSION['conf_types'][$element] == "text") {
+			$options[$element] = array($_POST[$element]);
+		}
+		// checkboxes
+		elseif ($_SESSION['conf_types'][$element] == "checkbox") {
+			if ($_POST[$element] == "on") $options[$element] = array('true');
+			else $options[$element] = array('false');
+		}
+		// dropdownbox
+		elseif ($_SESSION['conf_types'][$element] == "select") {
+			$options[$element] = array($_POST[$element]);
+		}
+		// multiselect
+		elseif ($_SESSION['conf_types'][$element] == "multiselect") {
+			$options[$element] = $_POST[$element];  // value is already an array
+		}
+	}
+
+	// get list of scopes of modules
+	$scopes = array();
+	for ($m = 0; $m < sizeof($types); $m++) {
+		$mods = $conf->get_AccountModules($types[$m]);
+		for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = $types[$m];
+	}
+	// check options
+	$errors = array_merge($errors, checkConfigOptions($scopes, $options));
+	// print error messages if any
+	if (sizeof($errors) > 0) {
+		$_SESSION['conf_errors'] = $errors;
+		$conf->set_moduleSettings($options);
+	}
+	// save settings if no errors occured
+	else {
+		// page head
+		echo $_SESSION['header'];
+		echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
+		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+		echo "</head><body>\n";
+		echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
+			"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr><br><br>");
+		$conf->set_moduleSettings($options);
+		$conf->save();
+		echo ("<br><br><br><br><br><a href=\"../login.php\" target=\"_top\">" . _("Back to Login") . "</a>");	
+		echo("</body></html>");
+		// remove settings from session
+		$sessionKeys = array_keys($_SESSION);
+		for ($i = 0; $i < sizeof($sessionKeys); $i++) {
+			if (substr($sessionKeys[$i], 0, 5) == "conf_") unset($_SESSION[$sessionKeys[$i]]);
+		}
+		exit();
+	}
+}
+
 ?>
 
