@@ -1,9 +1,9 @@
 <?php
 /*
-	$Id: delete.php,v 1.50 2005/10/15 09:33:05 gruberroland Exp $
+	$Id: delete.php,v 1.55 2006/05/16 15:18:24 gruberroland Exp $
 	
 	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-	Copyright (C) 2003  Tilo Lutz
+	Copyright (C) 2003 - 2006  Tilo Lutz
 	
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 */
 
 
+/** security functions */
+include_once("../lib/security.inc");
 /** account functions */
 include_once('../lib/account.inc');
 /** current configuration options */
@@ -43,8 +45,7 @@ include_once('../lib/lamdaemon.inc');
 include_once('../lib/modules.inc');
 
 // Start session
-session_save_path('../sess');
-@session_start();
+startSecureSession();
 
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
@@ -82,11 +83,15 @@ if ($_GET['type']) {
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_GET['type'] . "\">\n";
 	echo "<b>" . _("Do you really want to remove the following accounts?") . "</b>";
 	echo "<br><br>\n";
-	echo "<table border=0 width=\"100%\">\n<tr><td valign=\"top\" width=\"15%\" >";
+	echo "<table border=0>\n";
 	for ($i=0; $i<count($users); $i++) {
 		echo "<tr>\n";
 		echo "<td><b>" . _("Account name:") . "</b> $users[$i]</td>\n";
-		echo "<td><b>" . _('DN') . ":</b> " . $_SESSION['delete_dn'][$i] . "</td>\n";
+		echo "<td>&nbsp;&nbsp;<b>" . _('DN') . ":</b> " . $_SESSION['delete_dn'][$i] . "</td>\n";
+		$childCount = getChildCount($_SESSION['delete_dn'][$i]);
+		if ($childCount > 0) {
+			echo "<td>&nbsp;&nbsp;<b>" . _('Number of child entries') . ":</b> " . $childCount . "</td>\n";
+		}
 		echo "</tr>\n";
 	}
 	echo "</table>\n";
@@ -113,7 +118,7 @@ if ($_GET['type']) {
 
 if ($_POST['cancel']) {
 	if (isset($_SESSION['delete_dn'])) unset($_SESSION['delete_dn']);
-	metaRefresh("lists/list" . $_POST['type'] . "s.php");
+	metaRefresh("lists/list.php?type=" . $_POST['type']);
 }
 
 if ($_POST['delete']) {
@@ -213,11 +218,8 @@ if ($_POST['delete']) {
 			}
 		}
 		if (!$stopprocessing) {
-			$success = @ldap_delete($_SESSION['ldap']->server(), $_SESSION['delete_dn'][$m]);
-			if (!$success) {
-				$errors[] = array ('ERROR', sprintf(_('Was unable to delete DN: %s.'), $_SESSION['delete_dn'][$m]), ldap_error($_SESSION['ldap']->server()));
-				$stopprocessing = true;
-			}
+			$errors = deleteDN($_SESSION['delete_dn'][$m]);
+			if (sizeof($errors) > 0) $stopprocessing = true;
 		}
 		if (!$stopprocessing) {
 			echo sprintf(_('Deleted DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
@@ -240,4 +242,54 @@ if ($_POST['delete']) {
 
 }
 
+/**
+* Returns the number of child entries of a DN.
+*
+* @param string $dn DN of parent
+* @return interger number of childs
+*/
+function getChildCount($dn) {
+	$return = 0;
+	$sr = @ldap_search($_SESSION['ldap']->server, $dn, 'objectClass=*', array('dn'), 0);
+	if ($sr) {
+		$entries = ldap_get_entries($_SESSION['ldap']->server, $sr);
+		$return = $entries['count'] - 1;
+	}
+	return $return;
+}
+
+/**
+* Deletes a DN and all child entries.
+* 
+* @param string $dn DN to delete
+* @return array error messages
+*/
+function deleteDN($dn) {
+	$errors = array();
+	$sr = @ldap_list($_SESSION['ldap']->server, $dn, 'objectClass=*', array('dn'), 0);
+	if ($sr) {
+		$entries = ldap_get_entries($_SESSION['ldap']->server, $sr);
+		for ($i = 0; $i < $entries['count']; $i++) {
+			// delete recursively
+			$subErrors = deleteDN($entries[$i]['dn']);
+			for ($e = 0; $e < sizeof($subErrors); $e++) $errors[] = $subErrors[$e];
+		}
+	}
+	else {
+		$errors[] = array ('ERROR', sprintf(_('Was unable to delete DN: %s.'), $dn), ldap_error($_SESSION['ldap']->server()));
+	}
+	// delete parent DN
+	$success = @ldap_delete($_SESSION['ldap']->server(), $dn);
+	$ldapUser = $_SESSION['ldap']->decrypt_login();
+	$ldapUser = $ldapUser[0];
+	if (!$success) {
+		logNewMessage(LOG_ERR, '[' . $ldapUser .'] Unable to delete DN: ' . $dn . ' (' . ldap_err2str(ldap_errno($_SESSION['ldap']->server())) . ').');
+		$errors[] = array ('ERROR', sprintf(_('Was unable to delete DN: %s.'), $dn), ldap_error($_SESSION['ldap']->server()));
+	}
+	else {
+		logNewMessage(LOG_NOTICE, '[' . $ldapUser .'] Deleted DN: ' . $dn);
+	}
+	return $errors;
+}
+
 ?>
