@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: help.php,v 1.25 2005/09/12 15:37:23 gruberroland Exp $
+$Id: help.php,v 1.27 2006/05/07 09:02:52 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Michael Duergner
+  Copyright (C) 2003 - 2006  Michael Duergner
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,11 +26,8 @@ $Id: help.php,v 1.25 2005/09/12 15:37:23 gruberroland Exp $
 /**
  * LDAP Account Manager help page.
  * 
- * @author Michael Drgner
- * @version 0.5
+ * @author Michael Duergner
  * @package Help
- * @copyright Copyright (C) 2003-2004 Michael Drgner
- * @license GPL
  */
 
 /**
@@ -92,7 +89,7 @@ function echoHTMLFoot()
  */
 function displayHelp($helpEntry,$helpVariables) {
 	/* Load external help page */
-	if($helpEntry["ext"] == "TRUE")
+	if (isset($helpEntry["ext"]) && ($helpEntry["ext"] == "TRUE"))
 	{
 		echoHTMLHead();
 		include_once("../help/" . $helpEntry["Link"]);
@@ -106,7 +103,7 @@ function displayHelp($helpEntry,$helpVariables) {
 		$format = "		<p class=\"help\">" . $helpEntry['Text'] . "</p>\n";
 		array_unshift($helpVariables,$format);
 		call_user_func_array("printf",$helpVariables);
-		if(is_array($helpArray['SeeAlso'])) {
+		if(isset($helpArray['SeeAlso']) && is_array($helpArray['SeeAlso'])) {
 			while($current = current($helpEntry["SeeAlso"]))
 			{
 				echo '		<p class="help">' . (( isset($current['link'])) ? '<a class="helpSeeAlso" href="' . $current['link'] . '">' : '') . _('See also') . ': ' . $current['text'] . (( isset($current['link'])) ? '</a>' : '') . '</p>\n';
