@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: login.php,v 1.76 2005/09/30 13:53:45 gruberroland Exp $
+$Id: login.php,v 1.93 2006/05/23 14:46:58 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Michael Duergner
+  Copyright (C) 2003 - 2006  Michael Duergner
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,56 @@ $Id: login.php,v 1.76 2005/09/30 13:53:45 gruberroland Exp $
 * @package main
 */
 
+/** status messages */
+include_once("../lib/status.inc");
+/** security functions */
+include_once("../lib/security.inc");
+
+// check environment
+$criticalErrors = array();
+// check if PHP has session support
+if (! function_exists('session_start')) {
+	$criticalErrors[] = array("ERROR", "Your PHP has no session support!", "Please install the session extension for PHP.");
+}
+// check if PHP has LDAP support
+if (! function_exists('ldap_search')) {
+	$criticalErrors[] = array("ERROR", "Your PHP has no LDAP support!", "Please install the LDAP extension for PHP.");
+}
+// check if PHP has gettext support
+if (! function_exists('gettext') || !function_exists('_')) {
+	$criticalErrors[] = array("ERROR", "Your PHP has no gettext support!", "Please install gettext for PHP.");
+}
+// check if PHP has XML support
+if (! function_exists('utf8_decode')) {
+	$criticalErrors[] = array("ERROR", "Your PHP has no XML support!", "Please install the XML extension for PHP.");
+}
+// check file permissions
+$writableDirs = array('sess', 'tmp');
+for ($i = 0; $i < sizeof($writableDirs); $i++) {
+	$path = realpath('../') . "/" . $writableDirs[$i];
+	if (!is_writable($path)) {
+		$criticalErrors[] = array("ERROR", 'The directory %s is not writable for the web server. Please change your file permissions.', '', array($path));
+	}
+}
+// stop login if critical errors occured
+if (sizeof($criticalErrors) > 0) {
+	echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+	echo "<html>\n<head>\n";
+	echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
+	echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
+	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">";
+	echo "<title>LDAP Account Manager</title>\n";
+	echo "</head><body>\n";
+	for ($i = 0; $i < sizeof($criticalErrors); $i++) {
+		call_user_func_array("StatusMessage", $criticalErrors[$i]);
+		echo "<br><br>";
+	}
+	echo "</body></html>";
+	exit();
+}
+
+
 /** access to configuration options */
 include_once("../lib/config.inc"); // Include config.inc which provides Config class
 
@@ -44,14 +94,12 @@ function display_LoginPage($config_object) {
 	// generate 256 bit key and initialization vector for user/passwd-encryption
 	// check if we can use /dev/random otherwise use /dev/urandom or rand()
 	if(function_exists('mcrypt_create_iv')) {
-		$key = @mcrypt_create_iv(32, MCRYPT_DEV_RANDOM);
-		if (! $key) $key = @mcrypt_create_iv(32, MCRYPT_DEV_URANDOM);
+		$key = @mcrypt_create_iv(32, MCRYPT_DEV_URANDOM);
 		if (! $key) {
 			srand((double)microtime()*1234567);
 			$key = mcrypt_create_iv(32, MCRYPT_RAND);
 		}
-		$iv = @mcrypt_create_iv(32, MCRYPT_DEV_RANDOM);
-		if (! $iv) $iv = @mcrypt_create_iv(32, MCRYPT_DEV_URANDOM);
+		$iv = @mcrypt_create_iv(32, MCRYPT_DEV_URANDOM);
 		if (! $iv) {
 			srand((double)microtime()*1234567);
 			$iv = mcrypt_create_iv(32, MCRYPT_RAND);
@@ -118,36 +166,29 @@ function display_LoginPage($config_object) {
 		echo "</script>\n";
 	?>
 		<p align="center">
-			<a href="http://lam.sf.net" target="_blank"><img src="../graphics/banner.jpg" border="1" alt="LDAP Account Manager"></a>
+			<a href="http://lam.sourceforge.net" target="_blank"><img src="../graphics/banner.jpg" border="1" alt="LDAP Account Manager"></a>
 		</p>
 		<table width="100%" border="0">
 			<tr>
 				<td width="100%" align="right">
-					<a href="./config/conflogin.php" target="_self"><?php echo _("Configuration login"); ?></a>
+					<a href="./config/index.php"><IMG alt="configuration" src="../graphics/tools.png">&nbsp;<?php echo _("LAM configuration") ?></a>
 				</td>
 			</tr>
 		</table>
 		<hr><br><br>
 		<?php
-		// check if PHP has session support
-		if (! function_exists('session_start')) {
-			StatusMessage("ERROR", "Your PHP has no session support!", "Please install the session extension for PHP.");
-			echo "<br><br>";
+		// check extensions
+		$extList = getRequiredExtensions();
+		for ($i = 0; $i < sizeof($extList); $i++) {
+			if (!extension_loaded($extList[$i])) {
+				StatusMessage("ERROR", _("A required PHP extension is missing!"), $extList[$i]);
+				echo "<br>";
+			}
 		}
-		// check if all password hashes are possible
-		if ((! function_exists('mHash')) && (! function_exists('sha1'))) {
-			StatusMessage("INFO", "Your PHP does not support MHash or sha1(), you will only be able to use CRYPT/PLAIN/MD5/SMD5 for user passwords!", "Please install MHash or update to PHP >4.3.");
-			echo "<br><br>";
-		}
-		// check if PHP has LDAP support
-		if (! function_exists('ldap_search')) {
-			StatusMessage("ERROR", "Your PHP has no LDAP support!", "Please install the LDAP extension for PHP.");
-			echo "<br><br>";
-		}
-		// check if PHP has gettext support
-		if (! function_exists('gettext')) {
-			StatusMessage("ERROR", "Your PHP has no gettext support!", "Please install gettext for PHP.");
-			echo "<br><br>";
+		// check if session expired
+		if (isset($_GET['expired'])) {
+			StatusMessage("ERROR", _("Your session expired, please log in again."));
+			echo "<br>";
 		}
 		?>
 		<table width="650" align="center" border="2" rules="none" bgcolor="white">
@@ -160,7 +201,7 @@ function display_LoginPage($config_object) {
 						<table width="580">
 							<tr>
 								<td style="border-style:none" height="70" colspan="2" align="center">
-									<font color="darkblue"><b><big><?php echo _("Please select your user name and enter your password to log in"); ?></big></b></font>
+									<font color="darkblue"><b><big><?php echo _("Please select your user name and enter your password to log in."); ?></big></b></font>
 								</td>
 							</tr>
 							<tr>
@@ -256,8 +297,8 @@ function display_LoginPage($config_object) {
 							<tr>
 							<td style="border-style:none" height="30"><b>
 								<?php
-								echo _("Configuration profile") . ": ";
-								if(!$_POST['profileChange']) {
+								echo _("Server profile") . ": ";
+								if(empty($_POST['profileChange'])) {
 									$_POST['profile'] = $_SESSION['config']->file;
 								}
 								?></b>
@@ -301,7 +342,7 @@ function display_LoginPage($config_object) {
 }
 
 // checking if the submitted username/password is correct.
-if($_POST['checklogin'])
+if(!empty($_POST['checklogin']))
 {
 	$_SESSION['lampath'] = realpath('../') . "/";  // Save full path to lam in session
 
@@ -331,36 +372,42 @@ if($_POST['checklogin'])
 			$_SESSION['header'] .= "<html>\n<head>\n";
 			$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
 			$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
-
-			include("./main.php"); // Load main frame
+			// set security settings for session
+			$_SESSION['sec_session_id'] = session_id();
+			$_SESSION['sec_client_ip'] = $_SERVER['REMOTE_ADDR'];
+			$_SESSION['sec_sessionTime'] = time();
+			// logging
+			logNewMessage(LOG_NOTICE, 'User ' . $_POST['username'] . ' successfully logged in.');
+			// Load main frame
+			include("./main.php");
 		}
 		else
 		{
-			if ($result === False)
-			{
+			if ($result === False) {
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
 				display_LoginPage($_SESSION['config']); // connection failed
 			}
-			elseif ($result == 81)
-			{
+			elseif ($result == 81) {
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
 				display_LoginPage($_SESSION['config']); // connection failed
 			}
-			elseif ($result == 49)
-			{
+			elseif ($result == 49) {
 				$error_message = _("Wrong password/user name combination. Please try again.");
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (wrong password).');
 				display_LoginPage($_SESSION['config']); // Username/password invalid. Return to login page.
 			}
-			else
-			{
+			else {
 				$error_message = _("LDAP error, server says:") .  "\n<br>($result) " . ldap_err2str($result);
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
 				display_LoginPage($_SESSION['config']); // other errors
 			}
 		}
 	}
 }
 // Reload loginpage after a profile change
-elseif($_POST['profileChange']) {
+elseif(!empty($_POST['profileChange'])) {
 	$_SESSION['config'] = new Config($_POST['profile']); // Recreate the config object with the submited
 	display_LoginPage($_SESSION['config']); // Load login page
 }
@@ -371,6 +418,7 @@ else
 	$default_Config = new CfgMain();
 	$default_Profile = $default_Config->default;
 	$_SESSION["config"] = new Config($default_Profile); // Create new Config object
+	$_SESSION["cfgMain"] = $default_Config; // Create new CfgMain object
 
 	display_LoginPage($_SESSION["config"]); // Load Login page
 }
